@@ -386,13 +386,16 @@ def virtual_install_main_packages():
     f = open(os.path.join(os.path.dirname(__file__), 'orig-prefix.txt'))
     sys.real_prefix = f.read().strip()
     f.close()
+    pos = 2
+    if sys.path[0] == '':
+        pos += 1
     if sys.platform == 'win32':
         lib_path = os.path.join(sys.real_prefix, 'Lib')
-        sys.path.insert(1, lib_path)
-        sys.path.insert(2, os.path.join(sys.real_prefix, 'DLLs'))
+        sys.path.insert(pos, lib_path)
+        sys.path.insert(pos+1, os.path.join(sys.real_prefix, 'DLLs'))
     else:
         lib_path = os.path.join(sys.real_prefix, 'lib', 'python'+sys.version[:3])
-        sys.path.insert(1, lib_path)
+        sys.path.insert(pos, lib_path)
 
 def virtual_addsitepackages(known_paths):
     if not os.path.exists(os.path.join(os.path.dirname(__file__), 'no-global-site-packages.txt')):
